==> openshift-model-machineconfig-6.3.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigSpecFluentImpl<A extends ContainerRuntimeConfigSpecFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigSpecFluent<A>{
  public ContainerRuntimeConfigSpecFluentImpl() {
  }
  public ContainerRuntimeConfigSpecFluentImpl(ContainerRuntimeConfigSpec instance) {
    this.withContainerRuntimeConfig(instance.getContainerRuntimeConfig()); 
    this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ContainerRuntimeConfigurationBuilder containerRuntimeConfig;
  private LabelSelectorBuilder machineConfigPoolSelector;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerRuntimeConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfiguration getContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null ?this.containerRuntimeConfig.build():null;
  }
  public ContainerRuntimeConfiguration buildContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null ?this.containerRuntimeConfig.build():null;
  }
  public A withContainerRuntimeConfig(ContainerRuntimeConfiguration containerRuntimeConfig) {
    _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig);
    if (containerRuntimeConfig!=null){ this.containerRuntimeConfig= new ContainerRuntimeConfigurationBuilder(containerRuntimeConfig); _visitables.get("containerRuntimeConfig").add(this.containerRuntimeConfig);} else { this.containerRuntimeConfig = null; _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig); } return (A) this;
  }
  public Boolean hasContainerRuntimeConfig() {
    return this.containerRuntimeConfig != null;
  }
  public ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfig() {
    return new ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl();
  }
  public ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfigLike(ContainerRuntimeConfiguration item) {
    return new ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl(item);
  }
  public ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig());
  }
  public ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): new ContainerRuntimeConfigurationBuilder().build());
  }
  public ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfigLike(ContainerRuntimeConfiguration item) {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null ?this.machineConfigPoolSelector.build():null;
  }
  public LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null ?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} else { this.machineConfigPoolSelector = null; _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector); } return (A) this;
  }
  public Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(LabelSelector item) {
    return new ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new LabelSelectorBuilder().build());
  }
  public ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContainerRuntimeConfigSpecFluentImpl that = (ContainerRuntimeConfigSpecFluentImpl) o;
    if (containerRuntimeConfig != null ? !containerRuntimeConfig.equals(that.containerRuntimeConfig) :that.containerRuntimeConfig != null) return false;
    if (machineConfigPoolSelector != null ? !machineConfigPoolSelector.equals(that.machineConfigPoolSelector) :that.machineConfigPoolSelector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRuntimeConfig,  machineConfigPoolSelector,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerRuntimeConfig != null) { sb.append("containerRuntimeConfig:"); sb.append(containerRuntimeConfig + ","); }
    if (machineConfigPoolSelector != null) { sb.append("machineConfigPoolSelector:"); sb.append(machineConfigPoolSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerRuntimeConfigNestedImpl<N> extends ContainerRuntimeConfigurationFluentImpl<ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>> implements ContainerRuntimeConfigSpecFluent.ContainerRuntimeConfigNested<N>,Nested<N>{
    ContainerRuntimeConfigNestedImpl(ContainerRuntimeConfiguration item) {
      this.builder = new ContainerRuntimeConfigurationBuilder(this, item);
    }
    ContainerRuntimeConfigNestedImpl() {
      this.builder = new ContainerRuntimeConfigurationBuilder(this);
    }
    ContainerRuntimeConfigurationBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withContainerRuntimeConfig(builder.build());
    }
    public N endContainerRuntimeConfig() {
      return and();
    }
    
  }
  class MachineConfigPoolSelectorNestedImpl<N> extends LabelSelectorFluentImpl<ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>> implements ContainerRuntimeConfigSpecFluent.MachineConfigPoolSelectorNested<N>,Nested<N>{
    MachineConfigPoolSelectorNestedImpl(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new LabelSelectorBuilder(this);
    }
    LabelSelectorBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-6.7.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ContainerRuntimeConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerRuntimeConfigSpecFluentImpl<A extends ContainerRuntimeConfigSpecFluent<A>> extends BaseFluent<A> implements ContainerRuntimeConfigSpecFluent<A>{
  public ContainerRuntimeConfigSpecFluentImpl() {
  }
  public ContainerRuntimeConfigSpecFluentImpl(ContainerRuntimeConfigSpec instance) {
    if (instance != null) {
      this.withContainerRuntimeConfig(instance.getContainerRuntimeConfig());
      this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ContainerRuntimeConfigurationBuilder containerRuntimeConfig;
  private LabelSelectorBuilder machineConfigPoolSelector;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerRuntimeConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerRuntimeConfiguration getContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null ?this.containerRuntimeConfig.build():null;
  }
  public ContainerRuntimeConfiguration buildContainerRuntimeConfig() {
    return this.containerRuntimeConfig!=null ?this.containerRuntimeConfig.build():null;
  }
  public A withContainerRuntimeConfig(ContainerRuntimeConfiguration containerRuntimeConfig) {
    _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig);
    if (containerRuntimeConfig!=null){ this.containerRuntimeConfig= new ContainerRuntimeConfigurationBuilder(containerRuntimeConfig); _visitables.get("containerRuntimeConfig").add(this.containerRuntimeConfig);} else { this.containerRuntimeConfig = null; _visitables.get("containerRuntimeConfig").remove(this.containerRuntimeConfig); } return (A) this;
  }
  public Boolean hasContainerRuntimeConfig() {
    return this.containerRuntimeConfig != null;
  }
  public ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfig() {
    return new ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl();
  }
  public ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<A> withNewContainerRuntimeConfigLike(ContainerRuntimeConfiguration item) {
    return new ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNestedImpl(item);
  }
  public ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<A> editContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig());
  }
  public ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfig() {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): new ContainerRuntimeConfigurationBuilder().build());
  }
  public ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<A> editOrNewContainerRuntimeConfigLike(ContainerRuntimeConfiguration item) {
    return withNewContainerRuntimeConfigLike(getContainerRuntimeConfig() != null ? getContainerRuntimeConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null ?this.machineConfigPoolSelector.build():null;
  }
  public LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null ?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} else { this.machineConfigPoolSelector = null; _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector); } return (A) this;
  }
  public Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(LabelSelector item) {
    return new ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new LabelSelectorBuilder().build());
  }
  public ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerRuntimeConfigSpecFluentImpl that = (ContainerRuntimeConfigSpecFluentImpl) o;
    if (!java.util.Objects.equals(containerRuntimeConfig, that.containerRuntimeConfig)) return false;

    if (!java.util.Objects.equals(machineConfigPoolSelector, that.machineConfigPoolSelector)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRuntimeConfig,  machineConfigPoolSelector,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerRuntimeConfig != null) { sb.append("containerRuntimeConfig:"); sb.append(containerRuntimeConfig + ","); }
    if (machineConfigPoolSelector != null) { sb.append("machineConfigPoolSelector:"); sb.append(machineConfigPoolSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerRuntimeConfigNestedImpl<N> extends ContainerRuntimeConfigurationFluentImpl<ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<N>> implements ContainerRuntimeConfigSpecFluentImpl.ContainerRuntimeConfigNested<N>,Nested<N>{
    ContainerRuntimeConfigNestedImpl(ContainerRuntimeConfiguration item) {
      this.builder = new ContainerRuntimeConfigurationBuilder(this, item);
    }
    ContainerRuntimeConfigNestedImpl() {
      this.builder = new ContainerRuntimeConfigurationBuilder(this);
    }
    ContainerRuntimeConfigurationBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withContainerRuntimeConfig(builder.build());
    }
    public N endContainerRuntimeConfig() {
      return and();
    }
    
  }
  class MachineConfigPoolSelectorNestedImpl<N> extends LabelSelectorFluentImpl<ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<N>> implements ContainerRuntimeConfigSpecFluentImpl.MachineConfigPoolSelectorNested<N>,Nested<N>{
    MachineConfigPoolSelectorNestedImpl(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new LabelSelectorBuilder(this);
    }
    LabelSelectorBuilder builder;
    public N and() {
      return (N) ContainerRuntimeConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}
